@@ -12,103 +12,58 @@ from colorama import Fore, Style, init
 from typing import Optional, Dict, List, Any
 import shutil
 from pathlib import Path
+import tempfile
+import sys
+import site
 
 class TaskmanBackend:
     def __init__(self):
         """Initialize TaskMan backend"""
         try:
-            import ctypes
-            import time
-            from pathlib import Path
-            
-            # Check if running with admin privileges
-            def is_admin():
-                try:
-                    return ctypes.windll.shell32.IsUserAnAdmin()
-                except:
-                    return False
+            # Get user's Documents folder path
+            if os.name == 'nt':  # Windows
+                import winreg
+                with winreg.OpenKey(winreg.HKEY_CURRENT_USER, r"Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders") as key:
+                    documents_path = winreg.QueryValueEx(key, "Personal")[0]
+            else:  # Unix-like
+                documents_path = os.path.expanduser("~/Documents")
                 
-            # Use pathlib for better path handling
-            self.data_dir = Path.home() / ".taskman"
-            users_dir = self.data_dir / "users"
-            tasks_dir = self.data_dir / "tasks"
+            # Create absolute paths in Documents
+            self.data_dir = os.path.join(documents_path, "TaskmanSV_Data")
+            self.users_dir = os.path.join(self.data_dir, "users")
             
-            print(f"Initializing TaskMan directories:")
-            print(f"Data dir: {self.data_dir}")
-            print(f"Users dir: {users_dir}")
-            print(f"Tasks dir: {tasks_dir}")
+            print(f"Using Documents folder paths:")
+            print(f"Data directory: {self.data_dir}")
+            print(f"Users directory: {self.users_dir}")
             
-            if not is_admin():
-                print(f"{Fore.YELLOW}Warning: Running without administrator privileges.")
-                print("Some operations might fail due to insufficient permissions.")
-            
-            def ensure_directory(path: Path):
+            # Create directories with explicit paths and handle permissions
+            for directory in [self.data_dir, self.users_dir]:
                 try:
-                    # Convert to Path object if it isn't already
-                    path = Path(path)
+                    if not os.path.exists(directory):
+                        # Try to create with full permissions
+                        os.makedirs(directory, mode=0o777)
+                        print(f"Created directory: {directory}")
                     
-                    if not path.exists():
-                        path.mkdir(parents=True, exist_ok=True)
-                    elif not path.is_dir():
-                        path.unlink(missing_ok=True)  # Remove if it's a file
-                        time.sleep(0.1)  # Small delay
-                        path.mkdir(parents=True, exist_ok=True)
-                    
-                    # Verify the directory exists and is accessible
-                    if not path.is_dir():
-                        raise RuntimeError(f"Failed to create or verify directory: {path}")
-                    
-                    # Try to write a test file to verify permissions
-                    test_file = path / ".test"
+                    # Verify write permissions with a test file
+                    test_file = os.path.join(directory, ".write_test")
                     try:
-                        test_file.touch()
-                        test_file.unlink()
+                        with open(test_file, 'w') as f:
+                            f.write("test")
+                        os.remove(test_file)
                     except Exception as e:
-                        print(f"Warning: Directory {path} might not be writable: {e}")
-                    
+                        raise PermissionError(f"Cannot write to directory {directory}: {e}")
+                        
                 except Exception as e:
-                    print(f"Error handling directory {path}: {str(e)}")
+                    print(f"Error with directory {directory}: {e}")
                     raise
             
-            # Create directories
-            for directory in [self.data_dir, users_dir, tasks_dir]:
-                ensure_directory(directory)
+            print(f"TaskMan-SV initialized successfully")
             
-            # Convert paths back to strings for the rest of the code
-            self.data_dir = str(self.data_dir)
-            users_dir = str(users_dir)
-            tasks_dir = str(tasks_dir)
-            
-            # Set proper permissions
-            if os.name == 'nt':
-                self._set_windows_permissions(self.data_dir)
-                self._set_windows_permissions(users_dir)
-                self._set_windows_permissions(tasks_dir)
-            else:
-                os.chmod(self.data_dir, 0o700)
-                os.chmod(users_dir, 0o700)
-                os.chmod(tasks_dir, 0o700)
-            
-        except PermissionError as e:
-            print(f"{Fore.RED}Permission denied while creating TaskMan directories.")
-            print(f"Please try running the program as administrator or check folder permissions.")
-            print(f"Error details: {str(e)}")
-            raise
         except Exception as e:
             print(f"{Fore.RED}Error during initialization: {str(e)}")
+            print(f"Current user: {os.getenv('USERNAME')}")
             print(f"Current working directory: {os.getcwd()}")
-            print(f"Directory status:")
-            for path in [self.data_dir, users_dir, tasks_dir]:
-                path = Path(path)
-                print(f"{path}:")
-                print(f"  Exists: {path.exists()}")
-                print(f"  Is Directory: {path.is_dir() if path.exists() else 'N/A'}")
-                print(f"  Is File: {path.is_file() if path.exists() else 'N/A'}")
-                if path.exists() and path.is_dir():
-                    try:
-                        print(f"  Contents: {list(path.iterdir())}")
-                    except Exception as e:
-                        print(f"  Cannot list contents: {e}")
+            print(f"Process user: {os.getlogin()}")
             raise
 
     def generate_key(self, password: str, salt: bytes = None) -> tuple:
@@ -125,135 +80,214 @@ class TaskmanBackend:
         return key, salt
 
     def register_user(self, username: str, password: str) -> bool:
-        """Register a new user"""
+        """Register user with proper data structure"""
         try:
-            users_dir = os.path.join(self.data_dir, "users")
-            user_file = os.path.join(users_dir, f"{username}.json")
-
+            user_file = os.path.join(self.users_dir, f"{username}.json")
+            
             if os.path.exists(user_file):
                 print(f"{Fore.RED}Username already exists!")
                 return False
-
-            # Ensure users directory exists with proper permissions
-            if not os.path.exists(users_dir):
-                os.makedirs(users_dir)
-                if os.name == 'nt':
-                    self._set_windows_permissions(users_dir)
-                else:
-                    os.chmod(users_dir, 0o700)
-
+            
             # Generate salt and hash password
             salt = os.urandom(16)
             hashed = bcrypt.hashpw(password.encode(), bcrypt.gensalt())
             
             # Generate encryption key
             key, key_salt = self.generate_key(password, salt)
-
+            
+            # Create user data with proper structure
             user_data = {
                 "username": username,
                 "password": base64.b64encode(hashed).decode('utf-8'),
                 "salt": base64.b64encode(salt).decode('utf-8'),
                 "key_salt": base64.b64encode(key_salt).decode('utf-8'),
+                "data": {
+                    "notes": {},
+                    "tasks": {},
+                    "fastnotes": {}
+                }
             }
-
-            # Write user data with proper permissions
-            with open(user_file, 'w') as f:
-                json.dump(user_data, f)
             
-            # Set proper permissions for the user file
-            if os.name == 'nt':
-                self._set_windows_permissions(user_file)
-            else:
-                os.chmod(user_file, 0o600)
-
+            # Write to temporary file first
+            temp_file = user_file + '.tmp'
+            with open(temp_file, 'w') as f:
+                json.dump(user_data, f, indent=2)
+                
+            # Replace the original file
+            os.replace(temp_file, user_file)
+            
+            print(f"User registered successfully: {username}")
             return True
-
-        except PermissionError as e:
-            print(f"{Fore.RED}Permission denied while creating user file.")
-            print(f"Please ensure you have write permissions to {self.data_dir}")
-            return False
+            
         except Exception as e:
             print(f"{Fore.RED}Error during registration: {str(e)}")
+            if 'temp_file' in locals():
+                try:
+                    os.remove(temp_file)
+                except:
+                    pass
             return False
 
     def authenticate(self, username: str, password: str) -> bool:
         """Authenticate user and setup encryption"""
-        user_file = os.path.join(self.data_dir, "users", f"{username}.json")
-        
-        if not os.path.exists(user_file):
+        try:
+            user_file = os.path.join(self.users_dir, f"{username}.json")
+            
+            if not os.path.exists(user_file):
+                return False
+
+            with open(user_file, 'r') as f:
+                user_data = json.loads(f.read())
+            
+            stored_hash = base64.b64decode(user_data['password'].encode('utf-8'))
+            
+            if not bcrypt.checkpw(password.encode(), stored_hash):
+                return False
+
+            # Setup encryption
+            key_salt = base64.b64decode(user_data['key_salt'].encode('utf-8'))
+            self.key, _ = self.generate_key(password, key_salt)
+            self.fernet = Fernet(self.key)
+            self.user = username
+            self.user_file = user_file
+            
+            # Ensure data structure exists
+            if 'data' not in user_data:
+                user_data['data'] = {}
+            if 'notes' not in user_data['data']:
+                user_data['data']['notes'] = {}
+            if 'tasks' not in user_data['data']:
+                user_data['data']['tasks'] = {}
+            if 'fastnotes' not in user_data['data']:
+                user_data['data']['fastnotes'] = {}
+            
+            # Save the initialized structure
+            with open(user_file, 'w') as f:
+                json.dump(user_data, f, indent=2)
+            
+            print(f"User authenticated: {username}")
+            print(f"Available data types: {list(user_data['data'].keys())}")
+            return True
+            
+        except Exception as e:
+            print(f"{Fore.RED}Error during authentication: {str(e)}")
             return False
 
-        with open(user_file, 'r') as f:
-            user_data = json.load(f)
-
-        stored_hash = base64.b64decode(user_data['password'].encode('utf-8'))
-        if not bcrypt.checkpw(password.encode(), stored_hash):
-            return False
-
-        # Setup encryption key
-        key_salt = base64.b64decode(user_data['key_salt'].encode('utf-8'))
-        self.key, _ = self.generate_key(password, key_salt)
-        self.fernet = Fernet(self.key)
-        self.user = username
-        return True
-
     def save_data(self, data: dict, data_type: str) -> bool:
-        """Save encrypted data to file with restricted permissions"""
-        if not self.user or not self.fernet:
+        """Save data with proper structure"""
+        if not hasattr(self, 'user') or not hasattr(self, 'fernet'):
+            print(f"Debug: Missing user or fernet attributes")
             return False
 
-        filename = f"{self.user}_{data_type}.enc"
-        file_path = os.path.join(self.data_dir, "users", filename)
-        
         try:
-            # Double encryption for sensitive data
+            user_file = os.path.join(self.users_dir, f"{self.user}.json")
+            print(f"\nDebug: Saving {data_type} to {user_file}")
+            
+            # Read current data
+            with open(user_file, 'r') as f:
+                user_data = json.loads(f.read())
+            
+            print(f"Debug: Current user data keys: {list(user_data.keys())}")
+            
+            # Ensure data structure exists
+            if 'data' not in user_data:
+                print(f"Debug: Creating new data structure")
+                user_data['data'] = {}
+            
+            # Encrypt the data
+            print(f"Debug: Data to save: {type(data)}")
+            print(f"Debug: Data keys: {list(data.keys()) if isinstance(data, dict) else 'not a dict'}")
+            
             json_data = json.dumps(data).encode()
             encrypted_data = self.fernet.encrypt(json_data)
             
-            # Ensure parent directory exists and has correct permissions
-            parent_dir = os.path.dirname(file_path)
-            if not os.path.exists(parent_dir):
-                os.makedirs(parent_dir)
-                if os.name == 'nt':
-                    self._set_windows_permissions(parent_dir)
-                else:
-                    os.chmod(parent_dir, 0o700)
+            # Store with timestamp
+            user_data['data'][data_type] = {
+                'timestamp': int(time.time()),
+                'encrypted_data': encrypted_data.decode('utf-8')
+            }
             
-            # Write with restricted permissions
-            with open(file_path, 'wb') as f:
-                f.write(encrypted_data)
+            print(f"Debug: Updated data types: {list(user_data['data'].keys())}")
             
-            # Set file permissions after writing
-            if os.name == 'nt':
-                self._set_windows_permissions(file_path)
-            else:
-                os.chmod(file_path, 0o600)
+            # Write to temporary file first
+            temp_file = user_file + '.tmp'
+            with open(temp_file, 'w') as f:
+                json.dump(user_data, f, indent=2)
             
+            # Replace the original file
+            os.replace(temp_file, user_file)
+            
+            print(f"Debug: Successfully saved {data_type}")
             return True
-        
+            
         except Exception as e:
-            print(f"Error saving data: {str(e)}")
+            print(f"{Fore.RED}Error saving {data_type}: {str(e)}")
+            import traceback
+            print(f"Debug: Full traceback:")
+            print(traceback.format_exc())
+            if 'temp_file' in locals():
+                try:
+                    os.remove(temp_file)
+                except:
+                    pass
             return False
 
     def load_data(self, data_type: str) -> dict:
-        """Load and decrypt data from file"""
-        if not self.user or not self.fernet:
-            return None
-
-        filename = f"{self.user}_{data_type}.enc"
-        file_path = os.path.join(self.data_dir, "users", filename)
-        
-        if not os.path.exists(file_path):
-            return self.get_empty_data(data_type)
+        """Load data with proper structure"""
+        if not hasattr(self, 'user') or not hasattr(self, 'fernet'):
+            print(f"Debug: Missing user or fernet attributes")
+            return {}
 
         try:
-            with open(file_path, 'rb') as f:
-                encrypted_data = f.read()
-            decrypted_data = self.fernet.decrypt(encrypted_data)
-            return json.loads(decrypted_data)
+            user_file = os.path.join(self.users_dir, f"{self.user}.json")
+            print(f"\nDebug: Loading {data_type} from {user_file}")
+            
+            if not os.path.exists(user_file):
+                print(f"Debug: User file does not exist")
+                return {}
+            
+            # Read the data
+            with open(user_file, 'r') as f:
+                user_data = json.loads(f.read())
+            
+            print(f"Debug: User data keys: {list(user_data.keys())}")
+            
+            # Check data structure
+            if 'data' not in user_data:
+                print(f"Debug: No 'data' key in user_data")
+                return {}
+            
+            print(f"Debug: Available data types: {list(user_data['data'].keys())}")
+            
+            if data_type not in user_data['data']:
+                print(f"Debug: {data_type} not found in data")
+                return {}
+            
+            # Get the encrypted data
+            data_entry = user_data['data'][data_type]
+            print(f"Debug: Data entry keys: {list(data_entry.keys())}")
+            
+            encrypted_data = data_entry.get('encrypted_data')
+            if not encrypted_data:
+                print(f"Debug: No encrypted_data found for {data_type}")
+                return {}
+            
+            # Decrypt and return
+            decrypted_data = self.fernet.decrypt(encrypted_data.encode())
+            loaded_data = json.loads(decrypted_data)
+            
+            print(f"Debug: Successfully loaded {data_type} data")
+            print(f"Debug: Loaded data type: {type(loaded_data)}")
+            print(f"Debug: Loaded data keys: {list(loaded_data.keys()) if isinstance(loaded_data, dict) else 'not a dict'}")
+            
+            return loaded_data
+            
         except Exception as e:
-            print(f"Error loading {data_type}: {str(e)}")
-            return self.get_empty_data(data_type)
+            print(f"{Fore.RED}Error loading {data_type}: {str(e)}")
+            import traceback
+            print(f"Debug: Full traceback:")
+            print(traceback.format_exc())
+            return {}
 
     def get_empty_data(self, data_type: str) -> dict:
         """Return empty data structure based on type"""
